RingtoneSet class

A class for setting ringtones, notifications, alarms.

Constructors

RingtoneSet()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isWriteSettingsGranted → Future<bool>
Status of the WRITE_SETTINGS permission.
no setter
platformSdk → Future<int>
Android SDK version code.
no setter
platformVersion → Future<String>
Android version.
no setter

Static Methods

setAlarm(String asset) → Future<bool>
Sets alarm from asset path.
setAlarmFromFile(File file) → Future<bool>
Sets alarm from file.
setAlarmFromNetwork(String url) → Future<bool>
Sets alarm from network URL.
setNotification(String asset) → Future<bool>
Sets notification from asset path.
setNotificationFromFile(File file) → Future<bool>
Sets notification from file.
setNotificationFromNetwork(String url) → Future<bool>
Sets notification from network URL.
setRingtone(String asset) → Future<bool>
Sets ringtone from asset.
setRingtoneFromFile(File file) → Future<bool>
Sets ringtone from file.
setRingtoneFromNetwork(String url) → Future<bool>
Sets ringtone from network URL.